"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.shorthands = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const cli_utils_1 = require("@pnpm/cli-utils");
const common_cli_options_help_1 = require("@pnpm/common-cli-options-help");
const config_1 = require("@pnpm/config");
const error_1 = __importDefault(require("@pnpm/error"));
const pick_js_1 = __importDefault(require("ramda/src/pick.js"));
const render_help_1 = __importDefault(require("render-help"));
const list_1 = require("./list");
function rcOptionsTypes() {
    return (0, pick_js_1.default)([
        'dev',
        'global-dir',
        'global',
        'json',
        'long',
        'only',
        'optional',
        'parseable',
        'production',
    ], config_1.types);
}
exports.rcOptionsTypes = rcOptionsTypes;
const cliOptionsTypes = () => ({
    ...rcOptionsTypes(),
    recursive: Boolean,
});
exports.cliOptionsTypes = cliOptionsTypes;
exports.shorthands = {
    D: '--dev',
    P: '--production',
};
exports.commandNames = ['why'];
function help() {
    return (0, render_help_1.default)({
        description: `Shows the packages that depend on <pkg>
For example: pnpm why babel-* eslint-*`,
        descriptionLists: [
            {
                title: 'Options',
                list: [
                    {
                        description: 'Perform command on every package in subdirectories \
or on every workspace package, when executed inside a workspace. \
For options that may be used with `-r`, see "pnpm help recursive"',
                        name: '--recursive',
                        shortAlias: '-r',
                    },
                    {
                        description: 'Show extended information',
                        name: '--long',
                    },
                    {
                        description: 'Show parseable output instead of tree view',
                        name: '--parseable',
                    },
                    {
                        description: 'Show information in JSON format',
                        name: '--json',
                    },
                    {
                        description: 'List packages in the global install prefix instead of in the current project',
                        name: '--global',
                        shortAlias: '-g',
                    },
                    {
                        description: 'Display only the dependency graph for packages in `dependencies` and `optionalDependencies`',
                        name: '--prod',
                        shortAlias: '-P',
                    },
                    {
                        description: 'Display only the dependency graph for packages in `devDependencies`',
                        name: '--dev',
                        shortAlias: '-D',
                    },
                    {
                        description: "Don't display packages from `optionalDependencies`",
                        name: '--no-optional',
                    },
                    common_cli_options_help_1.OPTIONS.globalDir,
                    ...common_cli_options_help_1.UNIVERSAL_OPTIONS,
                ],
            },
            common_cli_options_help_1.FILTERING,
        ],
        url: (0, cli_utils_1.docsUrl)('why'),
        usages: [
            'pnpm why <pkg> ...',
        ],
    });
}
exports.help = help;
async function handler(opts, params) {
    if (params.length === 0) {
        throw new error_1.default('MISSING_PACKAGE_NAME', '`pnpm why` requires the package name');
    }
    return (0, list_1.handler)({
        ...opts,
        cliOptions: {
            ...(opts.cliOptions ?? {}),
            depth: Infinity,
        },
    }, params);
}
exports.handler = handler;
//# sourceMappingURL=why.js.map